@@ -31,285 +31,6 @@ except ModuleNotFoundError:
         return wrapper
 
 
-class VirtualMicroscopeManager:
-    """A low-level wrapper for TCP-IP communication (ESP32 REST API)"""
-
-    def __init__(self, rs232Info, name, **_lowLevelManagers):
-        self.__logger = initLogger(self, instanceName=name)
-        self._settings = rs232Info.managerProperties
-        self._name = name
-        availableImageModalities = ["simplant", "smlm"]
-        try:
-            self._imagePath = rs232Info.managerProperties["imagePath"]
-            if not self._imagePath in availableImageModalities:
-                raise NameError
-        except:
-            package_dir = os.path.dirname(os.path.abspath(__file__))
-            self._imagePath = os.path.join(
-                package_dir, "_data/images/histoASHLARStitch.jpg"
-            )
-            self.__logger.info(
-                "If you want to use the plant, use 'imagePath': 'simplant' in your setup.json"
-            )
-            defaultJSON = {
-                "rs232devices": {
-                    "VirtualMicroscope": {
-                        "managerName": "VirtualMicroscopeManager",
-                        "managerProperties": {"imagePath": "simplant"},
-                    }
-                }
-            }
-            self.__logger.info("Default JSON:" + str(defaultJSON))
-
-        self._virtualMicroscope = VirtualMicroscopy(self._imagePath)
-        self._positioner = self._virtualMicroscope.positioner
-        self._camera = self._virtualMicroscope.camera
-        self._illuminator = self._virtualMicroscope.illuminator
-        self._objective = None
-
-        """
-        # Test the functionality
-        for i in range(10):
-            microscope.positioner.move(x=5, y=5)
-            microscope.illuminator.set_intensity(intensity=1.5)
-            frame = microscope.get_frame()
-            cv2.imshow("Microscope View", frame)
-            cv2.waitKey(100)
-
-        cv2.destroyAllWindows()
-        """
-
-    def finalize(self):
-        self._virtualMicroscope.stop()
-
-
-class Camera:
-    def __init__(self, parent, filePath="path_to_image.jpeg"):
-        self._parent = parent
-        self.filePath = filePath
-
-        if self.filePath == "simplant":
-            self.image = createBranchingTree(width=5000, height=5000)
-            self.image /= np.max(self.image)
-        elif self.filePath == "smlm":
-            tmp = createBranchingTree(width=5000, height=5000)
-            tmp_min = np.min(tmp)
-            tmp_max = np.max(tmp)
-            self.image = (
-                1 - ((tmp - tmp_min) / (tmp_max - tmp_min)) > 0
-            )  # generating binary image
-        else:
-            self.image = np.mean(cv2.imread(filePath), axis=2)
-            self.image /= np.max(self.image)
-
-        self.lock = threading.Lock()
-        self.SensorHeight = 300  # self.image.shape[1]
-        self.SensorWidth = 400  # self.image.shape[0]
-        self.model = "VirtualCamera"
-        self.PixelSize = 1.0
-        self.isRGB = False
-        self.frameNumber = 0
-        # precompute noise so that we will save energy and trees
-        self.noiseStack = np.abs(
-            np.random.randn(self.SensorHeight, self.SensorWidth, 100) * 2
-        )
-
-    def produce_frame(
-        self, x_offset=0, y_offset=0, light_intensity=1.0, defocusPSF=None
-    ):
-        """Generate a frame based on the current settings."""
-        if self.filePath == "smlm": # There is likely a better way of handling this
-            return self.produce_smlm_frame(x_offset, y_offset, light_intensity)
-        else:
-            with self.lock:
-                # add moise
-                image = self.image.copy()
-                # Adjust image based on offsets
-                image = np.roll(
-                    np.roll(image, int(x_offset), axis=1), int(y_offset), axis=0
-                )
-                image = nip.extract(image, (self.SensorHeight, self.SensorWidth)) # extract the image to the sensor size
-
-                # do all post-processing on cropped image
-                if IS_NIP and defocusPSF is not None and not defocusPSF.shape == ():
-                    print("Defocus:" + str(defocusPSF.shape))
-                    image = np.array(np.real(nip.convolve(image, defocusPSF)))
-                image = np.float32(image) * np.float32(light_intensity)
-                image += self.noiseStack[:, :, np.random.randint(0, 100)]
-                
-
-                # Adjust illumination
-                image = image.astype(np.uint16)
-                time.sleep(0.1)
-                return np.array(image)
-
-    def produce_smlm_frame(self, x_offset=0, y_offset=0, light_intensity=5000):
-        """Generate a SMLM frame based on the current settings."""
-        with self.lock:
-            # add moise
-            image = self.image.copy()
-            # Adjust image based on offsets
-            image = np.roll(
-                np.roll(image, int(x_offset), axis=1), int(y_offset), axis=0
-            )
-            image = nip.extract(image, (self.SensorHeight, self.SensorWidth))
-
-            yc_array, xc_array = binary2locs(image, density=0.05)
-            photon_array = np.random.normal(
-                light_intensity * 5, light_intensity * 0.05, size=len(xc_array)
-            )
-
-            wavelenght = 6  # change to get it from microscope settings
-            wavelenght_std = 0.5  # change to get it from microscope settings
-            NA = 1.2  # change to get it from microscope settings
-            sigma = 0.21 * wavelenght / NA  # change to get it from microscope settings
-            sigma_std = (
-                0.21 * wavelenght_std / NA
-            )  # change to get it from microscope settings
-            sigma_array = np.random.normal(sigma, sigma_std, size=len(xc_array))
-
-            ADC_per_photon_conversion = 1.0  # change to get it from microscope settings
-            readout_noise = 50  # change to get it from microscope settings
-            ADC_offset = 100  # change to get it from microscope settings
-
-            out = FromLoc2Image_MultiThreaded(
-                xc_array,
-                yc_array,
-                photon_array,
-                sigma_array,
-                self.SensorHeight,
-                self.SensorWidth,
-                self.PixelSize,
-            )
-            out = (
-                ADC_per_photon_conversion * np.random.poisson(out)
-                + readout_noise
-                * np.random.normal(size=(self.SensorHeight, self.SensorWidth))
-                + ADC_offset
-            )
-            time.sleep(0.1)
-            return np.array(out)
-
-    def getLast(self, returnFrameNumber=False):
-        position = self._parent.positioner.get_position()
-        defocusPSF = np.squeeze(self._parent.positioner.get_psf())
-        intensity = self._parent.illuminator.get_intensity(1)
-        self.frameNumber += 1
-        if returnFrameNumber:
-            return (
-                self.produce_frame(
-                    x_offset=position["X"],
-                    y_offset=position["Y"],
-                    light_intensity=intensity,
-                    defocusPSF=defocusPSF,
-                ),
-                self.frameNumber,
-            )
-        else:
-            return self.produce_frame(
-                x_offset=position["X"],
-                y_offset=position["Y"],
-                light_intensity=intensity,
-                defocusPSF=defocusPSF,
-            )
-
-
-    def getLastChunk(self):
-        mFrame = self.getLast()
-        return np.expand_dims(mFrame, axis=0), [self.frameNumber] # we only provide one chunk, so we return a list with one element
-    
-    def setPropertyValue(self, propertyName, propertyValue):
-        pass
-
-
-class Positioner:
-    def __init__(self, parent):
-        self._parent = parent
-        self.position = {"X": 0, "Y": 0, "Z": 0, "A": 0}
-        self.mDimensions = (
-            self._parent.camera.SensorHeight,
-            self._parent.camera.SensorWidth,
-        )
-        self.lock = threading.Lock()
-        if IS_NIP:
-            self.psf = self.compute_psf(dz=0)
-        else:
-            self.psf = None
-
-    def move(self, x=None, y=None, z=None, a=None, is_absolute=False):
-        with self.lock:
-            if is_absolute:
-                if x is not None:
-                    self.position["X"] = x
-                if y is not None:
-                    self.position["Y"] = y
-                if z is not None:
-                    self.position["Z"] = z
-                    self.compute_psf(self.position["Z"])
-                if a is not None:
-                    self.position["A"] = a
-            else:
-                if x is not None:
-                    self.position["X"] += x
-                if y is not None:
-                    self.position["Y"] += y
-                if z is not None:
-                    self.position["Z"] += z
-                    self.compute_psf(self.position["Z"])
-                if a is not None:
-                    self.position["A"] += a
-
-    def get_position(self):
-        with self.lock:
-            return self.position.copy()
-
-    def compute_psf(self, dz):
-        dz = np.float32(dz)
-        print("Defocus:" + str(dz))
-        if IS_NIP and dz != 0:
-            obj = nip.image(np.zeros(self.mDimensions))
-            obj.pixelsize = (100.0, 100.0)
-            paraAbber = nip.PSF_PARAMS()
-            # aber_map = nip.xx(obj.shape[-2:]).normalize(1)
-            paraAbber.aberration_types = [paraAbber.aberration_zernikes.spheric]
-            paraAbber.aberration_strength = [np.float32(dz) / 10]
-            psf = nip.psf(obj, paraAbber)
-            self.psf = psf.copy()
-            del psf
-            del obj
-        else:
-            self.psf = None
-
-    def get_psf(self):
-        return self.psf
-
-
-class Illuminator:import os
-import cv2
-import math
-import time
-import threading
-import numpy as np
-import matplotlib.pyplot as plt
-
-from imswitch import IS_HEADLESS, __file__
-from imswitch.imcommon.model import initLogger
-
-try:
-    import NanoImagingPack as nip
-    IS_NIP = True
-except:
-    IS_NIP = False
-
-try:
-    from numba import njit, prange
-except ModuleNotFoundError:
-    prange = range
-    def njit(*args, **kwargs):
-        def wrapper(func):
-            return func
-        return wrapper
-
 
 class VirtualMicroscopeManager:
     """A low-level wrapper for TCP-IP communication (ESP32 REST API)
@@ -445,12 +166,6 @@ class Illuminator:
             return self.intensity
 
 
-class Objective:
-    def __init__(self, parent):
-        self._parent = parent
-        # Additional initialization for objective control can be added here
-
-
 class VirtualMicroscopy:
     def __init__(self, filePath="path_to_image.jpeg"):
         self.camera = Camera(self, filePath)
@@ -542,32 +257,150 @@ if __name__ == "__main__":
         plt.imsave(f"frame_{i}.png", frame)
     cv2.destroyAllWindows()
 
-    def __init__(self, parent):
-        self._parent = parent
-        self.intensity = 0
-        self.lock = threading.Lock()
-
-    def set_intensity(self, channel=1, intensity=0):
-        with self.lock:
-            self.intensity = intensity
-
-    def get_intensity(self, channel):
-        with self.lock:
-            return self.intensity
-
 class Objective:
     def __init__(self, parent):
         self._parent = parent
 
 
-class VirtualMicroscopy:
-    def __init__(self, filePath="path_to_image.jpeg"):
-        self.camera = Camera(self, filePath)
-        self.positioner = Positioner(self)
-        self.illuminator = Illuminator(self)
-        self.objective = Objective(self)
 
-    def stop(self):
+
+
+class Camera:
+    def __init__(self, parent, filePath="path_to_image.jpeg"):
+        self._parent = parent
+        self.filePath = filePath
+
+        if self.filePath == "simplant":
+            self.image = createBranchingTree(width=5000, height=5000)
+            self.image /= np.max(self.image)
+        elif self.filePath == "smlm":
+            tmp = createBranchingTree(width=5000, height=5000)
+            tmp_min = np.min(tmp)
+            tmp_max = np.max(tmp)
+            self.image = (
+                1 - ((tmp - tmp_min) / (tmp_max - tmp_min)) > 0
+            )  # generating binary image
+        else:
+            self.image = np.mean(cv2.imread(filePath), axis=2)
+            self.image /= np.max(self.image)
+
+        self.lock = threading.Lock()
+        self.SensorHeight = 300  # self.image.shape[1]
+        self.SensorWidth = 400  # self.image.shape[0]
+        self.model = "VirtualCamera"
+        self.PixelSize = 1.0
+        self.isRGB = False
+        self.frameNumber = 0
+        # precompute noise so that we will save energy and trees
+        self.noiseStack = np.abs(
+            np.random.randn(self.SensorHeight, self.SensorWidth, 100) * 2
+        )
+
+    def produce_frame(
+        self, x_offset=0, y_offset=0, light_intensity=1.0, defocusPSF=None
+    ):
+        """Generate a frame based on the current settings."""
+        if self.filePath == "smlm": # There is likely a better way of handling this
+            return self.produce_smlm_frame(x_offset, y_offset, light_intensity)
+        else:
+            with self.lock:
+                # add moise
+                image = self.image.copy()
+                # Adjust image based on offsets
+                image = np.roll(
+                    np.roll(image, int(x_offset), axis=1), int(y_offset), axis=0
+                )
+                image = nip.extract(image, (self.SensorHeight, self.SensorWidth)) # extract the image to the sensor size
+
+                # do all post-processing on cropped image
+                if IS_NIP and defocusPSF is not None and not defocusPSF.shape == ():
+                    print("Defocus:" + str(defocusPSF.shape))
+                    image = np.array(np.real(nip.convolve(image, defocusPSF)))
+                image = np.float32(image) * np.float32(light_intensity)
+                image += self.noiseStack[:, :, np.random.randint(0, 100)]
+                
+
+                # Adjust illumination
+                image = image.astype(np.uint16)
+                time.sleep(0.1)
+                return np.array(image)
+
+    def produce_smlm_frame(self, x_offset=0, y_offset=0, light_intensity=5000):
+        """Generate a SMLM frame based on the current settings."""
+        with self.lock:
+            # add moise
+            image = self.image.copy()
+            # Adjust image based on offsets
+            image = np.roll(
+                np.roll(image, int(x_offset), axis=1), int(y_offset), axis=0
+            )
+            image = np.array(nip.extract(image, (self.SensorHeight, self.SensorWidth)))
+
+            yc_array, xc_array = binary2locs(image, density=0.05)
+            photon_array = np.random.normal(
+                light_intensity * 5, light_intensity * 0.05, size=len(xc_array)
+            )
+
+            wavelenght = 6  # change to get it from microscope settings
+            wavelenght_std = 0.5  # change to get it from microscope settings
+            NA = 1.2  # change to get it from microscope settings
+            sigma = 0.21 * wavelenght / NA  # change to get it from microscope settings
+            sigma_std = (
+                0.21 * wavelenght_std / NA
+            )  # change to get it from microscope settings
+            sigma_array = np.random.normal(sigma, sigma_std, size=len(xc_array))
+
+            ADC_per_photon_conversion = 1.0  # change to get it from microscope settings
+            readout_noise = 50  # change to get it from microscope settings
+            ADC_offset = 100  # change to get it from microscope settings
+
+            out = FromLoc2Image_MultiThreaded(
+                xc_array,
+                yc_array,
+                photon_array,
+                sigma_array,
+                self.SensorHeight,
+                self.SensorWidth,
+                self.PixelSize,
+            )
+            out = (
+                ADC_per_photon_conversion * np.random.poisson(out)
+                + readout_noise
+                * np.random.normal(size=(self.SensorHeight, self.SensorWidth))
+                + ADC_offset
+            )
+            time.sleep(0.1)
+            return np.array(out)
+
+    def getLast(self, returnFrameNumber=False):
+        position = self._parent.positioner.get_position()
+        defocusPSF = np.squeeze(self._parent.positioner.get_psf())
+        intensity = self._parent.illuminator.get_intensity(1)
+        self.frameNumber += 1
+        if returnFrameNumber:
+            return (
+                self.produce_frame(
+                    x_offset=position["X"],
+                    y_offset=position["Y"],
+                    light_intensity=intensity,
+                    defocusPSF=defocusPSF,
+                ),
+                self.frameNumber,
+            )
+        else:
+            return self.produce_frame(
+                x_offset=position["X"],
+                y_offset=position["Y"],
+                light_intensity=intensity,
+                defocusPSF=defocusPSF,
+            )
+
+
+    def getLastChunk(self):
+        mFrame = self.getLast()
+        return np.expand_dims(mFrame, axis=0), [self.frameNumber] # we only provide one chunk, so we return a list with one element
+    
+    def setPropertyValue(self, propertyName, propertyValue):
         pass
 
 
